# Lewis Dijkstra, Metropolitan regions in the EU", EU Regional Focus 01/2009
# 
metro <- read.csv("Metropolitan regions in the EU - data metro.csv", stringsAsFactors = FALSE)
nuts3 <- read.csv("Metropolitan regions in the EU - data nuts3.csv", stringsAsFactors = FALSE)

library(dplyr)
metros <- full_join(nuts3, metro, by=c("METRO_NAME")) %>%
    subset(Type.of.City %in% c("Capital city region", "Second tier metro region")) %>%
    select(METRO_NAME, NUTS_ID, NUTS_NAME, Type.of.City) %>%
    mutate(COUNTRY = substr(NUTS_ID, 1, 2),
           NUTS1 = substr(NUTS_ID, 1, 3),
           NUTS2 = substr(NUTS_ID, 1, 4))

# Vienne extends beyond its NUTS2 (AT13) onto two NUTS3 regions (AT126 et AT127),
# but not enough to justify including the full corresponding NUTS2
metros <- filter(metros, NUTS1 != "AT12")

# Berlin et Hambourg also extend beyond their NUTS1 (DE3 et DE6),
# but we don't want to include the full surrounding Länder
metros <- filter(metros, !NUTS1 %in% c("DE4", "DE9", "DEF"))

# The list uses old NUTS1 codes for Italy
metros <- mutate(metros,
                 NUTS_ID = sub("ITD", "ITH", sub("ITE", "ITI", NUTS_ID)),
                 NUTS1 = sub("ITD", "ITH", sub("ITE", "ITI", NUTS1)),
                 NUTS2 = sub("ITD", "ITH", sub("ITE", "ITI", NUTS2)))

# Too many medium-sized metropolises in Romania,
# which cover a large part of the territory at the NUTS2 level
metros <- filter(metros, COUNTRY != "RO" | NUTS2 == "RO32")

# Only two NUTS2 in Slovenia, both including a metropolis
metros <- filter(metros, COUNTRY != "SI" | NUTS2 == "SI02")

# Since we only have NUTS1 for the United Kingdom, we cannot keep all metropolises, nor
# all NUTS3 surrounding London, or we would include amost all regions
# Only keep London, Manchester & Liverpool, Birmingham, Leeds-Bradford & Sheffield
metros <- filter(metros, COUNTRY != "UK" | NUTS1 %in% c("UKI", "UKD", "UKG", "UKE"))

# Countries with a single NUTS1: do not include in list of metropolises
metros <- filter(metros, !COUNTRY %in% c("EE", "LT", "LV", "NL"))

# Country without NUTS2 or with grouped NUTS2: use NUTS1
metros <- mutate(metros, NUTS2 = if_else(COUNTRY %in% c("AT", "BG", "DE", "FR", "GR", "ES", "UK") |
                                         NUTS1 == "SE3",
                                         NUTS1, NUTS2))

# Zagreb is not in the list
metros["HR04", "NUTS2"] <- "HR04"
metros["HR04", "COUNTRY"] <- "HR"
metros["HR04", "Type.of.City"] <- "Capital city region"


fix.nuts2 <- function(NUTS2) {
    # Go back to NUTS2010
    NUTS2 <- sub("EL", "GR", NUTS2)
    NUTS2[NUTS2 == "GR51"] <- "GR11"
    NUTS2[NUTS2 == "GR52"] <- "GR12"
    NUTS2[NUTS2 == "GR53"] <- "GR13"
    NUTS2[NUTS2 == "GR61"] <- "GR14"
    NUTS2[NUTS2 == "GR54"] <- "GR21"
    NUTS2[NUTS2 == "GR62"] <- "GR22"
    NUTS2[NUTS2 == "GR63"] <- "GR23"
    NUTS2[NUTS2 == "GR64"] <- "GR24"
    NUTS2[NUTS2 == "GR65"] <- "GR25"
    # Using only NUTS1, this is only an approximation
    NUTS2[NUTS2 == "GR5"] <- "GR1"
    NUTS2[NUTS2 == "GR6"] <- "GR2"

    NUTS2[NUTS2 == "SI03"] <- "SI01"
    NUTS2[NUTS2 == "SI04"] <- "SI02"
    
    # Use NUTS1 or NUTS0 when we do not have NUTS2
    pos <- substr(NUTS2, 1, 2) %in% c("AT", "CY", "DE", "GR", "LT", "LU", "LV", "UK", "NO", "NL")
    NUTS2[pos] <- sub("0+$", "", NUTS2[pos])
    NUTS2[NUTS2 == "CZ01"] <- "CZ02" # Merge Prague with surrounding region (too small)
    NUTS2
}
